INSERT/pyro-sync - Criterion.rs

## INSERT/pyro-sync

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0000006 | 0.0000007 | 0.0000006
Mean | 2.8592 ms | 2.9049 ms | 2.9529 ms
Std. Dev. | 200.89 µs | 240.67 µs | 277.55 µs
Median | 2.7530 ms | 2.8508 ms | 2.9686 ms
MAD | 136.73 µs | 261.83 µs | 309.34 µs

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.